@@ -1,7 +1,5 @@
 from django import forms
-from django.conf import settings
 from django.contrib.auth import get_user_model
-from django.contrib.auth.forms import ReadOnlyPasswordHashField
 from django.contrib.auth.forms import UserChangeForm
 from django.utils.translation import ugettext_lazy as _
 
@@ -11,11 +9,12 @@ class EmailUserCreationForm(forms.ModelForm):
     A form that creates a user, with no privileges, from the given email and
     password.
     """
-    password1 = forms.CharField(label=_('Password'), 
-        widget=forms.PasswordInput)
+    password1 = forms.CharField(label=_('Password'),
+                                widget=forms.PasswordInput)
     password2 = forms.CharField(label=_('Password confirmation'),
-        widget=forms.PasswordInput,
-        help_text=_('Enter the same password as above, for verification.'))
+                                widget=forms.PasswordInput,
+                                help_text=_('Enter the same password as '
+                                'above, for verification.'))
 
     class Meta:
         model = get_user_model()
