@@ -1,4 +1,4 @@
-from django.contrib.auth import authenticate, get_user_model
+from django.contrib.auth import get_user_model
 from rest_framework import serializers
 
 
@@ -9,10 +9,10 @@ class SignupSerializer(serializers.Serializer):
     """
     email = serializers.EmailField(max_length=255)
     password = serializers.CharField(max_length=128)
-    first_name = serializers.CharField(max_length=30, default='', 
-        required=False)
-    last_name = serializers.CharField(max_length=30, default='', 
-        required=False)
+    first_name = serializers.CharField(max_length=30, default='',
+                                       required=False)
+    last_name = serializers.CharField(max_length=30, default='',
+                                      required=False)
 
 
 class LoginSerializer(serializers.Serializer):
